@@ -6,11 +6,11 @@ CREATE TABLE dialplan (
     match_op INTEGER NOT NULL,
     match_exp VARCHAR(64) NOT NULL,
     match_flags INTEGER NOT NULL,
-    subst_exp VARCHAR(64) NOT NULL,
-    repl_exp VARCHAR(32) NOT NULL,
-    timerec VARCHAR(255) NOT NULL,
+    subst_exp VARCHAR(64),
+    repl_exp VARCHAR(32),
+    timerec VARCHAR(255),
     disabled INTEGER DEFAULT 0 NOT NULL,
-    attrs VARCHAR(32) NOT NULL
+    attrs VARCHAR(32)
 );
 
 ALTER SEQUENCE dialplan_id_seq MAXVALUE 2147483647 CYCLE;
